import { Http, Response } from "@angular/http";
import { Observable } from "rxjs";
export declare class HttpLocalAuthService {
    private http;
    private customHeaders;
    constructor(http: Http);
    /**
     * Wraps GET method
     * @param {string} url - The endpoint URL to be fetched.
     * @returns Observable
     */
    get(url: string): Observable<Response>;
    /**
     * Wraps POST method
     * @param {string} url - The endpoint URL to be fetched.
     * @param {Object} body - Payload request to be sent to server.
     * @returns Observable
     */
    post(url: string, body: any): Observable<Response>;
    /**
     * Wraps PUT method
     * @param {string} url - The endpoint URL to be fetched.
     * @param {Object} body - Payload request to be sent to server.
     * @returns Observable
     */
    put(url: string, body: any): Observable<Response>;
    /**
     * Wraps PATCH method
     * @param {string} url - The endpoint URL to be fetched.
     * @param {Object} body - Payload request to be sent to server.
     * @returns Observable
     */
    patch(url: string, body: any): Observable<Response>;
    /**
     * Wraps DELETE method
     * @param {string} url - The endpoint URL to be fetched.
     * @returns Observable
     */
    delete(url: string): Observable<Response>;
    /**
     * Appends headers for the next request
     * @param {Object} headerObject - Collection of headers to be appended.
     */
    addHeaders(headerObject: any): void;
    /**
     * Appends headers for the next request
     * @param {string} url - The endpoint URL to be fetched.
     * @param {RequestMethod} method - HTTP Verb method to be used.
     * @param {Object} body - Payload request to be sent to server.
     * @returns Observable
     */
    private _request(url, method, body?);
    /**
     * Creates Base request options to be used globally
     * @param {Object} reqData - Object containing request properties.
     */
    private createBaseRequestOptions(reqData);
    /**
     * Creates Authorization header to be used globally
     * @param {Headers} headers - Current Header data.
     */
    private createAuthorizationHeader(headers);
    /**
     * Appends custom headers defined before each request
     * @param {Headers} headers - Current Header data.
     */
    private appendCreatedHeaders(headers);
}
